@@ -3,7 +3,6 @@ from .onex_dataflowapi import Host
 from .onex_dataflowapi import HostIter
 from .onex_dataflowapi import Dataflow
 from .onex_dataflowapi import DataflowHostManagement
-from .onex_dataflowapi import DataflowHostManagementEthNic
 from .onex_dataflowapi import DataflowHostManagementIter
 from .onex_dataflowapi import DataflowWorkloadItem
 from .onex_dataflowapi import DataflowScatterWorkload
@@ -16,13 +15,15 @@ from .onex_dataflowapi import DataflowAllReduceWorkload
 from .onex_dataflowapi import DataflowBroadcastWorkload
 from .onex_dataflowapi import DataflowAlltoallWorkload
 from .onex_dataflowapi import DataflowFlowProfile
-from .onex_dataflowapi import DataflowFlowProfileEthernet
-from .onex_dataflowapi import DataflowFlowProfileIp
-from .onex_dataflowapi import DataflowFlowProfileTcp
+from .onex_dataflowapi import DataflowFlowProfileRdmaStack
+from .onex_dataflowapi import DataflowFlowProfileRdmaStackRoceV2
+from .onex_dataflowapi import DataflowFlowProfileTcpIpStack
+from .onex_dataflowapi import DataflowFlowProfileTcpIpStackIp
+from .onex_dataflowapi import DataflowFlowProfileL4ProtocolTcp
 from .onex_dataflowapi import L4PortRange
 from .onex_dataflowapi import L4PortRangeSingleValue
 from .onex_dataflowapi import L4PortRangeRange
-from .onex_dataflowapi import DataflowFlowProfileUdp
+from .onex_dataflowapi import DataflowFlowProfileL4ProtocolUdp
 from .onex_dataflowapi import DataflowFlowProfileIter
 from .onex_dataflowapi import GetConfigDetails
 from .onex_dataflowapi import ExperimentRequest
